@@ -35,12 +35,12 @@ extern "C" {
 #include "re_ice.h"
 #include "re_jbuf.h"
 #include "re_lock.h"
+#include "re_net.h"
 #include "re_main.h"
 #include "re_md5.h"
 #include "re_mem.h"
 #include "re_mod.h"
 #include "re_mqueue.h"
-#include "re_net.h"
 #include "re_odict.h"
 #include "re_json.h"
 #include "re_rtmp.h"
@@ -56,6 +56,7 @@ extern "C" {
 #include "re_sys.h"
 #include "re_tcp.h"
 #include "re_telev.h"
+#include "re_thread.h"
 #include "re_tmr.h"
 #include "re_trace.h"
 #include "re_tls.h"
@@ -64,6 +65,7 @@ extern "C" {
 #include "re_websock.h"
 #include "re_shim.h"
 #include "re_trice.h"
+#include "re_pcp.h"
 
 #ifdef __cplusplus
 }
